# eric7.CycloneDXInterface.CycloneDXConfigDialog

Module implementing a dialog to configure the CycloneDX SBOM generation.

### Global Attributes

None

### Classes

CycloneDXConfigDialog | Class implementing a dialog to configure the CycloneDX SBOM generation.

### Functions

None

## CycloneDXConfigDialog

Class implementing a dialog to configure the CycloneDX SBOM generation.

### Derived from

QDialog, Ui_CycloneDXConfigDialog

### Class Attributes

DefaultFileFormat
DefaultFileNames
Sources
SupportedSchemas

### Class Methods

None

### Methods

CycloneDXConfigDialog | Constructor
__editMetaData | Private slot to open a dialog for editing the SBOM metadata.
__repopulateSchemaVersionComboBox | Private slot to repopulate the schema version selector.
getData | Public method to get the SBOM configuration data.
on_fileFormatComboBox_currentTextChanged | Private slot to handle the selection of a SBOM file format.

### Static Methods

None

#### CycloneDXConfigDialog (Constructor)

CycloneDXConfigDialog(environment, parent=None)

Constructor

environment (str)
  name of the virtual environment
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### CycloneDXConfigDialog.__editMetaData

__editMetaData()

Private slot to open a dialog for editing the SBOM metadata.

#### CycloneDXConfigDialog.__repopulateSchemaVersionComboBox

__repopulateSchemaVersionComboBox()

Private slot to repopulate the schema version selector.

#### CycloneDXConfigDialog.getData

getData()

Public method to get the SBOM configuration data.

Return:
  tuple containing the input source, the input file name, the file format, the schema version, the path of the SBOM file to be written, a flag indicating to include vulnerability information, a flag indicating to include dependency information, a flag indicating to generate readable output and a dictionary containing the SBOM meta data

Return Type:
  tuple of (str, str, str, str, str, bool, bool, bool, dict)

#### CycloneDXConfigDialog.on_fileFormatComboBox_currentTextChanged

on_fileFormatComboBox_currentTextChanged(fileFormat)

Private slot to handle the selection of a SBOM file format.

fileFormat (str)
  selected format

Up